@@ -4,6 +4,8 @@ __all__ = [
     "State",
 ]
 
+TRAME_NON_INIT_VALUE = "__trame__: non_init_value_that_is_not_None"
+
 
 class StateChangeHandler:
     def __init__(self, listeners):
@@ -39,11 +41,22 @@ class State:
         self._state_listeners = StateChangeHandler(server._change_callbacks)
         self._push_state_fn = server._push_state
         self._change = server.change
+        #
+        self._pending_initialization = True
+
+    def server_ready(self):
+        self._pending_initialization = False
+        self.flush()
 
     def __getitem__(self, key):
         return self._pending_update.get(key, self._pushed_state.get(key))
 
     def __setitem__(self, key, value):
+        if key in self._pushed_state:
+            if value == self._pushed_state[key]:
+                self._pending_update.pop(key, None)
+                return
+
         self._pending_update[key] = value
 
     def __getattr__(self, key):
@@ -139,9 +152,15 @@ class State:
     def update(self, _dict):
         """Update the current state dict with the provided one"""
         self._pending_update.update(_dict)
+        for key in _dict:
+            if _dict[key] == self._pushed_state.get(key, TRAME_NON_INIT_VALUE):
+                self._pending_update.pop(key, None)
 
     def flush(self):
         """Force pushing modified state and execute any @state.change listener"""
+        if self._pending_initialization:
+            return
+
         keys = set()
         if len(self._pending_update):
             _keys = set(self._pending_update.keys())
